about summary refs log tree commit diff
path: root/third_party/git/perl/Git/SVN/Ra.pm
diff options
context:
space:
mode:
Diffstat (limited to 'third_party/git/perl/Git/SVN/Ra.pm')
-rw-r--r--third_party/git/perl/Git/SVN/Ra.pm4
1 files changed, 2 insertions, 2 deletions
diff --git a/third_party/git/perl/Git/SVN/Ra.pm b/third_party/git/perl/Git/SVN/Ra.pm
index 56ad9870bc..2cfe055a9a 100644
--- a/third_party/git/perl/Git/SVN/Ra.pm
+++ b/third_party/git/perl/Git/SVN/Ra.pm
@@ -486,11 +486,11 @@ sub gs_fetch_loop_common {
 			$reload_ra->() if $ra_invalid;
 		}
 		# pre-fill the .rev_db since it'll eventually get filled in
 		# with '0' x40 if something new gets committed
 		foreach my $gs (@$gsv) {
 			next if $gs->rev_map_max >= $max;
 			next if defined $gs->rev_map_get($max);
-			$gs->rev_map_set($max, 0 x40);
+			$gs->rev_map_set($max, 0 x $::oid_length);
 		}
 		foreach my $g (@$globs) {
 			my $k = "svn-remote.$g->{remote}.$g->{t}-maxRev";
@@ -486,11 +486,11 @@ sub gs_fetch_loop_common {
 		}
 		# pre-fill the .rev_db since it'll eventually get filled in
-		# with '0' x40 if something new gets committed
+		# with '0' x $oid_length if something new gets committed
 		foreach my $gs (@$gsv) {
 			next if $gs->rev_map_max >= $max;